@@ -1,8 +1,9 @@
 """Grabs Participant JSON data and outputs to files."""
 
 from dataclasses import dataclass, field
+import logging
 from rich import print  # type ignore
-
+from rich.logging import RichHandler # type ignore
 import time
 
 import eldonationtracker.utils.extralife_io
@@ -10,6 +11,11 @@ from eldonationtracker.api import donor as donor, team as team, donation as dona
 from eldonationtracker.utils import extralife_io as extralife_io
 from eldonationtracker import base_api_url
 
+# logging
+LOG_FORMAT = '%(name)s: %(message)s'
+logging.basicConfig(level=logging.INFO, format=LOG_FORMAT, handlers=[RichHandler(markup=True, show_path=False)])
+participant_log = logging.getLogger("Participant")
+
 
 class Participant:
     """Owns all the attributes under the participant API.
@@ -86,6 +92,7 @@ class Participant:
         # misc
         self._first_run: bool = True
         self._new_donation: bool = False
+        self._text_files_exist: bool = False
 
         self.set_config_values()
 
@@ -277,7 +284,7 @@ class Participant:
         """
         participant_json = extralife_io.get_json(self.participant_url)
         if not participant_json:
-            print("[bold red]Couldn't access participant JSON.[/bold red]")
+            participant_log.warning("[bold red]Couldn't access participant JSON.[/bold red]")
             return self.total_raised, self.number_of_donations, self.goal, self.avatar_image_url, self.event_name, \
                 self.donation_link_url, self.stream_url, self.extra_life_page_url, self.created_date_utc,\
                 self.stream_is_live, self.sum_pledges, self.team_name, self.is_team_captain, self.display_name
@@ -392,8 +399,11 @@ class Participant:
         """Update donor data."""
         if self.number_of_donations > 0:
             self._donor_list = self._get_donors()
-            self._ordered_donor_list = self._get_top_donors()
-            self._top_donor = self._ordered_donor_list[0]
+            # anonymous donors mess things up because they don't populate the donor API endpoint.
+            # So this check prevents a crash.
+            if self._donor_list:
+                self._ordered_donor_list = self._get_top_donors()
+                self._top_donor = self._ordered_donor_list[0]
 
     def _update_badges(self) -> None:
         """Add all our badges to the list."""
@@ -409,19 +419,32 @@ class Participant:
         json_response = extralife_io.get_json(self.incentive_url)
         self._incentives = [Incentive.create_incentive(incentive) for incentive in json_response]
 
+    def _check_existence_of_text_files(self) -> bool:
+        """This is a temporary hack until I resolve Github issue #162"""
+        value_in_total_raised = extralife_io.read_in_total_raised(self.text_folder)
+        if value_in_total_raised == "":
+            return False
+        # strip off the currency symbol
+        value_in_total_raised = value_in_total_raised.lstrip("$")
+        if float(value_in_total_raised) > 0:
+            return True
+        else:
+            return True
+
     def output_donation_data(self) -> None:
         """Write out text files for donation data.
 
         If there have been donations, format the data (eg horizontally, vertically, etc) and output to text files.
         If there have not yet been donations, write default data to the files.
         """
+        self._text_files_exist = self._check_existence_of_text_files()
         if len(self._donation_list) > 0:
             self._format_donation_information_for_output()
             self.write_text_files(self._donation_formatted_output)
             if self._top_donation is not None:
                 self.write_text_files(self._top_donation_formatted_output)
-        else:
-            print("[bold blue]No donations, writing default data to files.[/bold blue]")
+        elif not self._text_files_exist:
+            participant_log.info("[bold blue]No donations, writing default data to files.[/bold blue]")
             self.write_text_files(self._donation_formatted_output)
 
     def output_donor_data(self) -> None:
@@ -430,13 +453,15 @@ class Participant:
         If there have been donations, format the data (eg horizontally, vertically, etc) and output to text files.
         If there have not yet been donations, write default data to the files.
         """
+        self._text_files_exist = self._check_existence_of_text_files()
         if len(self._donation_list) > 0:
             self._format_donor_information_for_output()
             self.write_text_files(self._donor_formatted_output)
             if self._top_donor is not None:
                 self.write_text_files(self._top_donor_formatted_output)
-        else:
-            print("[bold blue]No donors or only anonymous donors, writing default data to files.[/bold blue]")
+        elif not self._text_files_exist:
+            participant_log.info("[bold blue]No donors or only anonymous donors, writing default data to files.[/bold "
+                                 "blue]")
             self.write_text_files(self._top_donor_formatted_output)
 
     def output_milestone_data(self) -> None:  # pragma: no cover
@@ -493,7 +518,9 @@ class Participant:
             self.update_donation_data()
             self.output_donation_data()
             self.update_donor_data()
-            self.output_donor_data()
+            # again, below is necessary because anonymous donors don't appear on the donor API endpoint.
+            if self._donor_list:
+                self.output_donor_data()
             self._update_badges()
             extralife_io.output_badge_data(self.badges, self.text_folder)
             self._update_milestones()
@@ -503,7 +530,7 @@ class Participant:
             self.my_team.team_run()
         ##########################################################
         self._first_run = False
-        print(time.strftime("%H:%M:%S"))
+        participant_log.info("Finished checking API and updating text files!")
 
     def __str__(self):
         if self.my_team:
